/*
 * (c) Copyright IBM Corp 2001, 2005 
 */

package com.ibm.wsdl.tck.mime;

import com.ibm.wsdl.tck.util.*;
import java.io.*;
import java.util.*;
import javax.wsdl.*;
import javax.wsdl.extensions.*;
import javax.wsdl.extensions.mime.*;
import javax.wsdl.factory.*;
import javax.wsdl.xml.*;
import javax.xml.namespace.*;
import junit.framework.*;

/**
 * This class implements a series of tests used to check
 * javax.wsdl.extensions.mime.MIMEMimeXml implementations
 * for compliance with the JWSDL specification.
 *
 * @author Matthew J. Duftler (duftler@us.ibm.com)
 */
public class MIMEMimeXmlTest extends TestCase
{
  private static final String TEST_CANDIDATE_PROPERTY_NAME =
    "javax.wsdl.factory.WSDLFactoryCandidate";
  private static final String NS_URI_MIME =
    "http://schemas.xmlsoap.org/wsdl/mime/";

  private WSDLFactory factory = null;
  private ExtensionRegistry extReg = null;
  private MIMEMimeXml mimeMimeXml = null;

  protected void setUp() throws WSDLException, IOException
  {
    // Determine name of JWSDL factory implementation to test.
    String testCandidateName =
      System.getProperty(TEST_CANDIDATE_PROPERTY_NAME);

    if (testCandidateName == null)
    {
      throw new IllegalArgumentException("System property '" +
                                         TEST_CANDIDATE_PROPERTY_NAME +
                                         "' must be specified to run " +
                                         "test suite.");
    }

    factory = WSDLFactory.newInstance(testCandidateName);

    Assert.assertNotNull("WSDLFactory should not be null.", factory);

    extReg = factory.newPopulatedExtensionRegistry();

    Assert.assertNotNull("ExtensionRegistry should not be null.", extReg);

    QName mimeMimeXmlQName = new QName(NS_URI_MIME, "mimeXml");

    mimeMimeXml = (MIMEMimeXml)TCKUtils.createExtension(extReg,
                                                        BindingInput.class,
                                                        mimeMimeXmlQName,
                                                        MIMEMimeXml.class);
  }

  /**
   * Test MIMEMimeXml.setPart(...) and MIMEMimeXml.getPart().
   */
  public void testSetGetPart()
  {
    String part = "abcdef";

    mimeMimeXml.setPart(part);

    String part2 = mimeMimeXml.getPart();

    Assert.assertTrue("MIMEMimeXml.getPart() did not return " +
                      "the same part that was set using " +
                      "MIMEMimeXml.setPart(...).",
                      part.equals(part2));
  }
}